<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bn">
<context>
    <name>MircastShowWidget</name>
    <message>
        <source>Projecting... 
Please do not exit the Movie app during the process.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit Miracast</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MircastWidget</name>
    <message>
        <source>Project to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Searching for devices...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Miracast display devices were found. Please connect the device and your computer to the same WLAN network.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Invalid folder</source>
        <translation>ফোল্ডারটি অবৈধ</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>ফোল্ডার খুলুন</translation>
    </message>
    <message>
        <source>Network disconnected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>আপনার কাছে এই ফোল্ডারটি পরিচালনা করার অনুমতি নেই</translation>
    </message>
    <message>
        <source>Auto add similar files to play</source>
        <translation>একই ধরণের ফাইলগুলো অটোমেটিক চলার জন্য যুক্ত করুন</translation>
    </message>
    <message>
        <source>Clear playlist when exit</source>
        <translation>বের হয়ে যাবার সময় চলার তালিকা মুছে ফেলুন</translation>
    </message>
    <message>
        <source>Show video preview on mouseover</source>
        <translation>মাউস নেওয়ার সাথে সাথেই ভিডিওর প্রিভিউ দেখান। </translation>
    </message>
    <message>
        <source>Open a new player for each file played</source>
        <translation>প্রত্যেকটি ফাইল চলতে নতুন প্লেয়ার খুলুন</translation>
    </message>
    <message>
        <source>Pause when minimized</source>
        <translation>মিনিমাইজ করলে থেমে যান</translation>
    </message>
    <message>
        <source>Remember playback position</source>
        <translation>সর্বশেষ চালানো অবস্থা মনে রাখুন</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>পথ </translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>প্রাথমিক</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>চালু করুন</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation> স্ক্রিনশট</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>শর্টকাট</translation>
    </message>
    <message>
        <source>File</source>
        <translation>ফাইল </translation>
    </message>
    <message>
        <source>Frame/Sound</source>
        <translation>ফ্রেম/শব্দ </translation>
    </message>
    <message>
        <source>Playback</source>
        <translation>চালান </translation>
    </message>
    <message>
        <source>Subtitle</source>
        <translation>সাবটাইটেল</translation>
    </message>
    <message>
        <source>Font Style</source>
        <translation>ফন্ট স্টাইল</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>পূর্বনির্ধারিত জিনিসে ফিরে যান</translation>
    </message>
    <message>
        <source>Open file</source>
        <translation>ফাইল খুলুন</translation>
    </message>
    <message>
        <source>Open next</source>
        <translation>পরবর্তীটি খুলুন</translation>
    </message>
    <message>
        <source>Open previous</source>
        <translation>পূর্ববর্তীটি খুলুন</translation>
    </message>
    <message>
        <source>Mini mode</source>
        <translation>ছোট রূপ</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>নীরব</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>পরবর্তী ফ্রেম</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>পূর্বের ফ্রেম</translation>
    </message>
    <message>
        <source>Volume down</source>
        <translation>শব্দ কমান</translation>
    </message>
    <message>
        <source>Volume up</source>
        <translation>শব্দ বাড়ান</translation>
    </message>
    <message>
        <source>Speed up</source>
        <translation>গতি বাড়ান</translation>
    </message>
    <message>
        <source>Speed down</source>
        <translation>গতি কমান</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>সম্পূর্ণ পর্দা</translation>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation>থামুন/চালান </translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation>চালানোর তালিকা</translation>
    </message>
    <message>
        <source>Reset speed</source>
        <translation>গতি পুনরায় সেট করুন</translation>
    </message>
    <message>
        <source>Rewind</source>
        <translation>আবার গুটিয়ে নিন</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>সামনে</translation>
    </message>
    <message>
        <source>Film screenshot</source>
        <translation>ফিল্ম স্ক্রিনশট</translation>
    </message>
    <message>
        <source>0.5s backward</source>
        <translation>0.5s পিছনে</translation>
    </message>
    <message>
        <source>0.5s forward</source>
        <translation>0.5s সামনে</translation>
    </message>
    <message>
        <source>Font</source>
        <translation>ফন্ট</translation>
    </message>
    <message>
        <source>Exit fullscreen/mini mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Movie</source>
        <translation>মুভি</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>সেটিংস</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>সাহায্য করুন</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete from playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Film info</source>
        <translation>ফিল্মের তথ্য</translation>
    </message>
    <message>
        <source>Burst shooting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size</source>
        <translation>সাইজ</translation>
    </message>
    <message>
        <source>Movie is a full-featured video player, supporting playing local and streaming media in multiple video formats.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show thumbnails in progress bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default play mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">ঠিক আছে</translation>
    </message>
    <message>
        <source>Decoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto select (Recommended)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hardware decoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Software decoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Customize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decode mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The custom decoding method needs to be restarted before it can take effect,
and whether to restart it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rendering engine</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UrlDialog</name>
    <message>
        <source>Cancel</source>
        <translation>বাতিল</translation>
    </message>
    <message>
        <source>Please enter the URL:</source>
        <translation>দয়াকরে URL প্রবেশ করান</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ঠিক আছে</translation>
    </message>
</context>
<context>
    <name>dmr::ActionFactory</name>
    <message>
        <source>Settings</source>
        <translation>সেটিংস</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>সম্পূর্ণ পর্দা</translation>
    </message>
    <message>
        <source>Always on Top</source>
        <translation>সবসময় উপরে</translation>
    </message>
    <message>
        <source>Empty playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Film info</source>
        <translation>ফিল্মের তথ্য</translation>
    </message>
    <message>
        <source>Open file</source>
        <translation>ফাইল খুলুন</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>ফোল্ডার খুলুন</translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation>URL খুলুন</translation>
    </message>
    <message>
        <source>Open CD/DVD</source>
        <translation>CD/DVD খুলুন</translation>
    </message>
    <message>
        <source>Mini Mode</source>
        <translation>ছোট রূপ</translation>
    </message>
    <message>
        <source>Play Mode</source>
        <translation>চালানোর ধরণ</translation>
    </message>
    <message>
        <source>Order Play</source>
        <translation>ধারাবাহিকভাবে চালান</translation>
    </message>
    <message>
        <source>Shuffle Play</source>
        <translation>অদলবদল করে চালান</translation>
    </message>
    <message>
        <source>Single Play</source>
        <translation>একটিমাত্র চালান</translation>
    </message>
    <message>
        <source>Single Loop</source>
        <translation>একবার ঘুড়ুন</translation>
    </message>
    <message>
        <source>List Loop</source>
        <translation>সম্পূর্ণ তালিকা বার বার ঘুড়ুন</translation>
    </message>
    <message>
        <source>Frame</source>
        <translation>ফ্রেম</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>পূর্বনির্ধারিত</translation>
    </message>
    <message>
        <source>Clockwise</source>
        <translation>ঘড়ির কাটার দিকে</translation>
    </message>
    <message>
        <source>Counterclockwise</source>
        <translation>ঘড়ির কাটার বিপরীত দিকে</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>শব্দ</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>চ্যানেল</translation>
    </message>
    <message>
        <source>Stereo</source>
        <translation>স্টেরিও</translation>
    </message>
    <message>
        <source>Left channel</source>
        <translation>বামদিকের চ্যানেল</translation>
    </message>
    <message>
        <source>Right channel</source>
        <translation>ডানদিকের চ্যানেল</translation>
    </message>
    <message>
        <source>Track</source>
        <translation>রেকর্ড করা শব্দ</translation>
    </message>
    <message>
        <source>Subtitle</source>
        <translation>সাবটাইটেল</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>লোড করুন</translation>
    </message>
    <message>
        <source>Online Search</source>
        <translation>অনলাইনে খুজুন</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>নির্বাচন করুন</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>লুকান</translation>
    </message>
    <message>
        <source>Encodings</source>
        <translation>এনকোডিং</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation> স্ক্রিনশট</translation>
    </message>
    <message>
        <source>Film Screenshot</source>
        <translation>ফিল্ম স্ক্রিনশট</translation>
    </message>
    <message>
        <source>Burst Shooting</source>
        <translation>অনেকগুলি স্ক্রিনশট</translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation>চলার তালিকা</translation>
    </message>
    <message>
        <source>Film Info</source>
        <translation>ফিল্মের তথ্য</translation>
    </message>
    <message>
        <source>Delete from playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>ফাইল ম্যানেজার দেখান</translation>
    </message>
    <message>
        <source>Next Frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous Frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open screenshot folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Playback Speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0.5x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.0x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.2x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.5x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2.0x</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::BurstScreenshotsDialog</name>
    <message>
        <source>Duration: %1</source>
        <translation>সময়কাল: %1</translation>
    </message>
    <message>
        <source>Resolution: %1</source>
        <translation>রেজূূলিউশন: %1</translation>
    </message>
    <message>
        <source>Size: %1</source>
        <translation>আকার: %1</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>সংরক্ষণ করুন</translation>
    </message>
</context>
<context>
    <name>dmr::MainWindow</name>
    <message>
        <source>Load successfully</source>
        <translation>সফলভাবে লোড হয়েছে</translation>
    </message>
    <message>
        <source>Load failed</source>
        <translation>লোড করতে বার্থ হয়েছে</translation>
    </message>
    <message>
        <source>Buffering...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>ফোল্ডার খুলুন</translation>
    </message>
    <message>
        <source>Stereo</source>
        <translation>স্টেরিও</translation>
    </message>
    <message>
        <source>Left channel</source>
        <translation>বামদিকের চ্যানেল</translation>
    </message>
    <message>
        <source>Right channel</source>
        <translation>ডানদিকের চ্যানেল</translation>
    </message>
    <message>
        <source>Parse failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>নীরব</translation>
    </message>
    <message>
        <source>Volume: %1%</source>
        <translation>শব্দ: %1%</translation>
    </message>
    <message>
        <source>Track: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subtitle %1: %2s</source>
        <translation>সাবটাইটেল %1: %2s</translation>
    </message>
    <message>
        <source>delayed</source>
        <translation>বিলম্ব করা হয়েছে</translation>
    </message>
    <message>
        <source>advanced</source>
        <translation>অ্যাডভান্সড</translation>
    </message>
    <message>
        <source>Speed: %1x</source>
        <translation>গতি: %1x</translation>
    </message>
    <message>
        <source>View</source>
        <translation>দেখুন</translation>
    </message>
    <message>
        <source>Saved to</source>
        <translation>এখানে সংরক্ষণ করুন</translation>
    </message>
    <message>
        <source>The screenshot is saved</source>
        <translation>স্ক্রিনশটটি সংরক্ষণ করা হয়েছে</translation>
    </message>
    <message>
        <source>Failed to save the screenshot</source>
        <translation>স্ক্রিনশট সংরক্ষণ করতে বার্থ হয়েছে</translation>
    </message>
    <message>
        <source>Invalid file: %1</source>
        <translation>অবধৈ ফাইল: %1</translation>
    </message>
    <message>
        <source>No matching online subtitles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot open file or stream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No video file found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Film screenshot</source>
        <translation>ফিল্ম স্ক্রিনশট</translation>
    </message>
    <message>
        <source>Taking the screenshots, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ঠিক আছে</translation>
    </message>
    <message>
        <source>Please insert a CD/DVD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reading DVD files...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4K video may be stuck</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shuffle play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>List loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The CD/DVD has been ejected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please load the video first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please exit smart dock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot play the disc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to adjust the subtitle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The action is not supported in this video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
        <comment>All (*)</comment>
        <translation type="unfinished">সাবটাইটেল (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Miracast disconnected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">বাতিল</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfo</name>
    <message>
        <source>%1G</source>
        <translation type="vanished">%1G</translation>
    </message>
    <message>
        <source>%1M</source>
        <translation type="vanished">%1M</translation>
    </message>
    <message>
        <source>%1K</source>
        <translation type="vanished">%1K</translation>
    </message>
    <message>
        <source>%1</source>
        <translation type="vanished">%1</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfoDialog</name>
    <message>
        <source>Film info</source>
        <translation>ফিল্মের তথ্য</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>রেজোলিউশন</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size</source>
        <translation>সাইজ</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>পথ </translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FPS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 fps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1</source>
        <translation type="unfinished">%1</translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 bits</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 bps</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::MpvProxy</name>
    <message>
        <source>Internal</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::Platform_MainWindow</name>
    <message>
        <source>Load successfully</source>
        <translation type="unfinished">সফলভাবে লোড হয়েছে</translation>
    </message>
    <message>
        <source>Load failed</source>
        <translation type="unfinished">লোড করতে বার্থ হয়েছে</translation>
    </message>
    <message>
        <source>Cannot play the disc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Parse failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="unfinished">ফোল্ডার খুলুন</translation>
    </message>
    <message>
        <source>All (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Speed: %1x</source>
        <translation type="unfinished">গতি: %1x</translation>
    </message>
    <message>
        <source>Stereo</source>
        <translation type="unfinished">স্টেরিও</translation>
    </message>
    <message>
        <source>Left channel</source>
        <translation type="unfinished">বামদিকের চ্যানেল</translation>
    </message>
    <message>
        <source>Right channel</source>
        <translation type="unfinished">ডানদিকের চ্যানেল</translation>
    </message>
    <message>
        <source>Track: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to adjust the subtitle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subtitle %1: %2s</source>
        <translation type="unfinished">সাবটাইটেল %1: %2s</translation>
    </message>
    <message>
        <source>delayed</source>
        <translation type="unfinished">বিলম্ব করা হয়েছে</translation>
    </message>
    <message>
        <source>advanced</source>
        <translation type="unfinished">অ্যাডভান্সড</translation>
    </message>
    <message>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
        <comment>All (*)</comment>
        <translation type="unfinished">সাবটাইটেল (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
    </message>
    <message>
        <source>View</source>
        <translation type="unfinished">দেখুন</translation>
    </message>
    <message>
        <source>Film screenshot</source>
        <translation type="unfinished">ফিল্ম স্ক্রিনশট</translation>
    </message>
    <message>
        <source>Saved to</source>
        <translation type="unfinished">এখানে সংরক্ষণ করুন</translation>
    </message>
    <message>
        <source>The screenshot is saved</source>
        <translation type="unfinished">স্ক্রিনশটটি সংরক্ষণ করা হয়েছে</translation>
    </message>
    <message>
        <source>Failed to save the screenshot</source>
        <translation type="unfinished">স্ক্রিনশট সংরক্ষণ করতে বার্থ হয়েছে</translation>
    </message>
    <message>
        <source>Taking the screenshots, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reading DVD files...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No matching online subtitles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4K video may be stuck</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">ঠিক আছে</translation>
    </message>
    <message>
        <source>Order play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shuffle play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>List loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Buffering...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mute</source>
        <translation type="unfinished">নীরব</translation>
    </message>
    <message>
        <source>Volume: %1%</source>
        <translation type="unfinished">শব্দ: %1%</translation>
    </message>
    <message>
        <source>Cannot open file or stream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please insert a CD/DVD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No video file found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please load the video first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please exit smart dock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The CD/DVD has been ejected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The action is not supported in this video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid file: %1</source>
        <translation type="unfinished">অবধৈ ফাইল: %1</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Miracast disconnected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">বাতিল</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::Platform_PlayItemWidget</name>
    <message>
        <source>The file does not exist</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::Platform_PlaylistWidget</name>
    <message>
        <source>Playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty</source>
        <translation type="unfinished">খালি করুন</translation>
    </message>
    <message>
        <source>%1 videos</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::Platform_ToolboxProxy</name>
    <message>
        <source>Play/Pause</source>
        <translation type="unfinished">চালান/থামুন</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation type="unfinished">পূর্ববর্তী</translation>
    </message>
    <message>
        <source>Next</source>
        <translation type="unfinished">পরবর্তী</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished">সম্পূর্ণ পর্দা</translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation type="unfinished">সম্পূর্ণ পর্দা থেকে বের হয়ে যান</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished">থামুন</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished">চালু করুন</translation>
    </message>
    <message>
        <source>Miracast</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::PlayItemWidget</name>
    <message>
        <source>The file does not exist</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::PlaylistWidget</name>
    <message>
        <source>Playlist</source>
        <translation>চলার তালিকা</translation>
    </message>
    <message>
        <source>%1 videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>খালি করুন</translation>
    </message>
</context>
<context>
    <name>dmr::Settings</name>
    <message>
        <source>%1/Movie%2(%3).jpg</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shuffle play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>List loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::ToolboxProxy</name>
    <message>
        <source>Play</source>
        <translation>চালু করুন</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>পূর্ববর্তী</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>পরবর্তী</translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation>চলার তালিকা</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>সম্পূর্ণ পর্দা</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>চালান/থামুন</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>সম্পূর্ণ পর্দা থেকে বের হয়ে যান</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>থামুন</translation>
    </message>
    <message>
        <source>Miracast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Volume</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::VolumeButton</name>
    <message>
        <source>Volume</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
